
local addon      = KiwiPlates
local widget     = addon:newWidget( 'Target', { 'target' } )
local SendColor  = addon.SendColor
local kvPlates   = addon.kvPlates
local PlatesSetAlpha    = addon.PlatesSetAlpha
local PlateSendToBack   = addon.PlateSendToBack
local PlateBringToFront = addon.PlateBringToFront
local PlateSetHighlight = addon.PlateSetHighlightTexture

local targetDB
local opaqueNT
local plateAlpha
local colorEnabled
local kHighlight
local kPlateTarget

local function Update(kPlate,bPlate)
	if bPlate.isTarget then
		kPlateTarget = kPlate	
		PlateBringToFront( kPlate, bPlate, 'Target', 128 )
		if colorEnabled then
			SendColor.Target( kPlate, targetDB.glowColor )
		end
		local db = kPlate.db.Target
		if db and not db.disableHighlight then
		    PlateSetHighlight( kPlate, kHighlight, 'Target')
		end	
	else
		PlateSendToBack( kPlate, bPlate, 'Target', 128 )
		if colorEnabled then
			SendColor.Target( kPlate )
		end
	end
end

local function Hide(kPlate)
	if kPlate == kPlateTarget then
		kHighlight:Hide()
		if colorEnabled then
			SendColor.Target( kPlate )
		end
		kPlateTarget = nil
	end
end

local function TargetChanged( newTarget, oldTarget )
	if opaqueNT and ( not newTarget ~= not oldTarget ) then
		PlatesSetAlpha(newTarget and plateAlpha or 1)
	end
	if not newTarget then
		kHighlight:Hide()
	end
end

function widget:OnEnable(addon, theme )
	targetDB = theme.Target
	if targetDB then
		plateAlpha   = theme.Plate.alpha or 1
		opaqueNT     = targetDB.opaqueWhenNoTarget
		colorEnabled = targetDB.colorReceivers and #targetDB.colorReceivers>0
		kHighlight   = kHighlight or CreateFrame( 'Frame' )
		addon.RegisterNotify( 'PlateShow', Update )
		addon.RegisterNotify( 'PlateHide', Hide )	
		addon.RegisterNotify( 'PlateTargetUpdate', Update )
		addon.RegisterNotify( 'TargetChanged', TargetChanged )
		addon.RegisterColorSender( 'Target', targetDB.colorReceivers, targetDB.colorPriority or 5)
		addon.PlatesSetAlpha( addon.TargetGUID and addon.theme.Plate.alpha or 1 )
	end	
end

function widget:OnDisable(addon)
	addon.UnregisterNotify( 'PlateShow', Update )
	addon.UnregisterNotify( 'PlateHide', Hide )		
	addon.UnregisterNotify( 'PlateTargetUpdate', Update )
	addon.UnregisterNotify( 'TargetChanged', TargetChanged )
	addon.UnregisterColorSender( 'Target')
end
