
local addon   = KiwiPlates
local status  = addon:newStatus( 'target' )
local PlateSkinRules = addon.PlateSkinRules
local Notify  = addon.Notify
local bPlates = addon.bvPlates
local plateOfGuid
local bPlateTarget

-- Used by mouseover status to set the target if target was not detected, this is an unfixed glitch: 
-- some times target nameplate is not detected because nameplate becomes visible but its alpha value is not equal to 1.
local function SetTargetPlate(bPlate)
	bPlateTarget = bPlate
	bPlate.isTarget = true
	local guid = addon.TargetGUID
	if guid and guid ~= bPlate.guid then
		addon.StoreGUID(guid, bPlate, 'target')
	end	
	local kPlate = bPlate.kPlate	
	if kPlate then
		Notify.PlateTargetUpdate( kPlate, bPlate, true ) 		
		if PlateSkinRules.target then addon.ReSkinPlate(bPlate) end				
	end	
end

local function SearchTargetPlate()
	local guid = UnitGUID('target')
	addon.TargetGUID = guid
	if guid then
		local bPlate = plateOfGuid[guid]
		if bPlate then
			bPlate.isTarget = true
			return bPlate
		end
		for i=#bPlates,1,-1 do
			local bPlate = bPlates[i]
			if bPlate:GetAlpha() > 0.9 then
				bPlate.isTarget = true
				addon.StoreGUID(guid, bPlate, 'target')
				return bPlate
			end
		end
	end	
end

local function TargetChanged()
	local bPlateOld = bPlateTarget
	bPlateTarget = SearchTargetPlate()
	if bPlateOld then
		bPlateOld.isTarget = false
		local kPlate = bPlateOld.kPlate
		if kPlate then
			Notify.PlateTargetUpdate( kPlate, bPlateOld, false )		
			if PlateSkinRules.target then addon.ReSkinPlate(bPlateOld)	end	
		end	
	end
	if bPlateTarget then
		local kPlate = bPlateTarget.kPlate
		if kPlate then
			Notify.PlateTargetUpdate( kPlate, bPlateTarget, true ) 		
			if PlateSkinRules.target then addon.ReSkinPlate(bPlateTarget) end	
		end
	end	
	Notify.TargetChanged( addon.TargetGUID, bPlateOld and bPlateOld.guid )
end

local function PlayerTargetChanged()
	addon.RunOnUpdate( TargetChanged )
end

local function PlateShow(bPlate)
	local isTarget = addon.TargetGUID and bPlate:GetAlpha() > 0.9
	if isTarget then
		bPlateTarget = bPlate
		bPlate.isTarget = isTarget
		addon.StoreGUID(addon.TargetGUID, bPlate, 'target')
	end
end

local function PlateHide(bPlate)
	if bPlate.isTarget then
		bPlateTarget = nil
		bPlate.isTarget = nil
	end
end

function status:OnEnable(addon, dbx)
	plateOfGuid = addon.bPlateOfGuid
	addon.TargetGUID = UnitGUID('target')
	addon.RegisterNotify('bPlateShow', PlateShow )
	addon.RegisterNotify('bPlateHide', PlateHide )
	addon:RegisterEvent( 'PLAYER_TARGET_CHANGED', PlayerTargetChanged )
	addon:RegisterEvent( 'ZONE_CHANGED_NEW_AREA', PlayerTargetChanged )
	addon:RegisterEvent( 'PLAYER_ENTERING_WORLD', PlayerTargetChanged )
end

function status:OnDisable(addon)
	if bPlateTarget then bPlateTarget.isTarget = nil end
	addon.UnregisterNotify('bPlateShow', PlateShow )		
	addon.UnregisterNotify('bPlateHide', PlateHide )
	addon:UnregisterEvent( 'PLAYER_TARGET_CHANGED' )
	addon:UnregisterEvent( 'ZONE_CHANGED_NEW_AREA')	
	addon:UnregisterEvent( 'PLAYER_ENTERING_WORLD')
end

-- Public Objects
addon.TargetGUID     = nil
addon.GetTargetPlate = function() return bPlateTarget end
addon.SetTargetPlate = SetTargetPlate
