--[[ Simple DataBroker launcher for KiwiPlates. Created by Michael --]]

local DataBroker = LibStub("LibDataBroker-1.1", true)
if not DataBroker then return end

local MenuShow

local KiwiPlatesLDB = DataBroker:NewDataObject("KiwiPlates", {
	type  = "launcher",
	label = GetAddOnInfo("KiwiPlates", "Title"),
	icon  = "Interface\\AddOns\\KiwiPlates\\media\\kiwi",
	OnClick = function(self, button)
		if button=="LeftButton" then
			KiwiPlates:OnChatCommand("kiwiplates")
		elseif button=="RightButton" then
			MenuShow()
		end
	end,
	OnTooltipShow = function(tooltip)
		tooltip:AddLine("|cFF7FFF72Kiwi Plates|r")
		tooltip:AddDoubleLine( "Player Role",  KiwiPlates.PlayerRole or "Unknown", 255,255,255, 255,255,0)
		tooltip:AddDoubleLine( "Theme", KiwiPlates.theme and KiwiPlates.theme.name or "", 255,255,255, 255,255,0)
		tooltip:AddLine("|cFFff4040Left Click|r to open configuration\n|cFFff4040Right Click|r to open menu", 0.2, 1, 0.2)
	end,
})

local icon = LibStub("LibDBIcon-1.0")
if icon then
	if not KiwiPlates.db.minimapIcon then
		KiwiPlates.db.minimapIcon = {}
	end	
	icon:Register("KiwiPlates", KiwiPlatesLDB, KiwiPlates.db.minimapIcon)
	KiwiPlates.minimapIcon = icon
end

-- Popup menu
do
	local menuFrame
	local menuTable = {}
	local function SetTheme(self)
		KiwiPlates:ThemeUpdate(self.value)
	end
	local function SetVisibility(self)
		if not InCombatLockdown() then
			SetCVar(self.value, self.checked() and 0 or 1)
		end
	end
	local function CreateMenuTable()
		wipe(menuTable)
		menuTable[1] = { text = '|cFF7FFF72KiwiPlates Theme|r',  notCheckable= true, isTitle = true }
		for k,v in next, KiwiPlates.themes do
			menuTable[#menuTable+1] = { func = SetTheme, text = k, value = k, checked = function() return k == KiwiPlates.theme.name end }
		end
		menuTable[#menuTable+1] = { text = '|cFF7FFF72KiwiPlates Visibility|r',  notCheckable= true, isTitle = true }
		menuTable[#menuTable+1] = { func = SetVisibility, text = 'Enemies', value = 'nameplateShowEnemies', isNotRadio = true, keepShownOnClick = 1, checked = function() return GetCVar('nameplateShowEnemies')~='0' end }
		menuTable[#menuTable+1] = { func = SetVisibility, text = 'Friends', value = 'nameplateShowFriends', isNotRadio = true, keepShownOnClick = 1, checked = function() return GetCVar('nameplateShowFriends')~='0' end }
	end
	MenuShow= function()
		menuFrame = menuFrame or CreateFrame("Frame", "KiwiPlatesLDBPopupMenu", UIParent, "UIDropDownMenuTemplate")
		CreateMenuTable()
		EasyMenu(menuTable, menuFrame, "cursor", 0 , 0, "MENU", 1)
	end
end
