----------------------------------------------------------------
-- Squared Themes
----------------------------------------------------------------

local defaults    = KiwiPlates.defaults
local FONT        = defaults.fonts.STANDARD
local FONT_SMALL  = defaults.fonts.SMALL
local TRANSPARENT = defaults.color.transparent
local HIGHLIGHT   = defaults.color.highlight 
local WHITE       = defaults.color.white
local BLACK       = defaults.color.black
local RED         = defaults.color.red
local DARKGRAY    = { .1,.1,.1,1 }

----------------------------------------------------------------

KiwiPlates:RegisterTheme( 'Squared', {
	Plate = {
		alpha = 0.4,
	},
	Skins = { { 'Squared.Standard' } },
	Target = {
		glowColor    = { 0, .8, 1, 1 },
		colorReceivers = { "GlowBorder" },
		colorPriority = 7,
		opaqueWhenNoTarget = true,	
	},
	Mouseover = {
		alpha = 1,
		layer = 'OVERTARGET',
		glowColor = { 0, .8, 1, 0.5 },
		colorReceivers = { "GlowBorder" },
		colorPriority = 6,
	},
	Reaction = {
		npcColorize    = "reaction",
		playerColorize = "reaction",
		colors = defaults.colors.Reaction,
		colorReceivers = { 'HealthBar' },
		colorPriority = 1,		
	},	
	Classification = {
		colors = defaults.colors.Classification,
		colorReceivers = { 'LevelText' },
		colorPriority = 2,
	},	
	Threat = {
		colors = defaults.colors.Threat,
		colorReceivers = { "GlowBorder", "NameText" },
		colorPriority = 9,
	},
	CastBar = {
		interruptibleColor =  WHITE,
		uninterruptibleColor = RED,
	},
	TargetIcon = { opaqueRaidIcons = false },
} )

KiwiPlates:RegisterTheme( 'Squared.Tank', {
	Plate = {
		alpha = 0.4,
	},
	Skins = { { 'Squared.Standard' } },
	Target = {
		glowColor    = { 0, .8, 1, 1 },
		colorReceivers = { "GlowBorder" },
		colorPriority = 9,
		opaqueWhenNoTarget = true,
	},
	Mouseover = {
		alpha = 1,
		layer = 'OVERTARGET',
		glowEnabled = true,
		glowColor = { 0, 1, 0, 0.5 },
		colorReceivers = { "GlowBorder" },
		colorPriority = 6,
	},
	Reaction = {
		npcColorize    = "reaction",
		playerColorize = "class",
		colors = defaults.colors.Reaction,
		colorReceivers = { 'HealthBar' },
		colorPriority = 1,		
	},	
	Classification = {
		colors = defaults.colors.Classification,
		colorReceivers = { 'LevelText' },
		colorPriority = 2,
	},	
	Threat = {
		bringToFront = true,
		colors = defaults.colors.ThreatTank,
		colorReceivers = { "HealthBar" },
		colorPriority = 9,
	},
	CastBar = {
		interruptibleColor = WHITE,
		uninterruptibleColor = RED,
	},
	TargetIcon = { opaqueRaidIcons = false },	
} )

----------------------------------------------------------------
-- Skins
----------------------------------------------------------------

KiwiPlates:RegisterSkin( 'Squared.Standard' , {
	Plate = { 
		left = 0, top = 0, width  = 130, height =  15, 
	},
	Target    = { disableHighlight = false, color = HIGHLIGHT },
	Mouseover = { disableHighlight = false, color = HIGHLIGHT },
	GlowBorder = {
		acceptColors = true,
		color = TRANSPARENT,
	},
	HealthBar = {
		acceptColors = true,	
		barTexture  = 'Gradient',
		color 		= WHITE,
		backColor   = DARKGRAY,
		borderColor = BLACK,
		borderSize  = 1,
	},
	HealthText = {
		acceptColors = true,		
		hideAtFullHealth = false,
		left = false, top = false,	width = false, height = false,
		fontName = FONT,
		fontColor = WHITE,		
		fontSize =  10,
		fontFlags = 'OUTLINE',
		JustifyH = 'CENTER',
		JustifyV = 'MIDDLE',
		textFormat = 3,		
	},	
	NameText = {
		acceptColors = true,
		left = 0, top = 15,	width = false, height = 20,
		fontName = FONT,
		fontColor = WHITE,
		fontSize =  11,
		fontFlags = 'OUTLINE',
		JustifyH = 'CENTER',
		JustifyV = 'BOTTOM',
	},
	LevelText = {
		acceptColors = true,	
		left = false, top = false,	width = false, height = false,
		fontName = FONT,
		fontColor = WHITE,
		fontSize =  10,
		fontFlags = 'OUTLINE',
		JustifyH = 'RIGHT',
		JustifyV = 'MIDDLE',
	},
	TargetIcon = {
		left = 0, top = 16, width = 22, height = 22,
	},
	CastBar = {
		left = 0, top = -15, width = false, height = 12,		
		barTexture = 'Gradient',
		backColor = { 0.1, 0.1, 0.1, 1 },
		borderSize = 1,
		borderColor = BLACK,
		SpellIcon = {
			left = -81, top = 8, width = 26, height = 26,
			borderSize  = 1,
			borderColor = BLACK,
		},
		SpellText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  9,
			fontFlags = 'OUTLINE',
			JustifyH = 'LEFT',
			JustifyV = 'MIDDLE',
			AdjustX = 0,
			AdjustY = 0,
		},
		TimeText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  9,
			fontFlags = 'OUTLINE',
			JustifyH = 'RIGHT',
			JustifyV = 'MIDDLE',
			AdjustX = 0,
			AdjustY = 0,
		},
	},
	Auras = {
		left = -54, top = 27, 
		auraWidth = 22, auraHeight = 16, auraSpacing = 2,
		borderSize = 1,
		borderColor = BLACK,
		TimeText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  11,
			fontFlags = 'OUTLINE',
			JustifyH = 'LEFT',
			JustifyV = 'TOP',
			AdjustX = -1,
			AdjustY = 8,
		},
		CountText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  9,
			fontFlags = 'OUTLINE',
			JustifyH = 'RIGHT',
			JustifyV = 'BOTTOM',	
			AdjustX = 0,
			AdjustY = 0,
		},
	},
} )

KiwiPlates:RegisterSkin( 'Squared.Medium' , {
	Plate = { 
		left = 0, top = -10, width = 100, height =  13, 
	},
	Target    = { disableHighlight = false, color = HIGHLIGHT },
	Mouseover = { disableHighlight = false, color = HIGHLIGHT },
	GlowBorder = {
		acceptColors = true,
		color = TRANSPARENT,
	},
	HealthBar = {
		acceptColors = true,
		barTexture  = 'Gradient',
		color 		= WHITE,
		backColor   = DARKGRAY,
		borderColor = BLACK,
		borderSize  = 1,
	},
	HealthText = {
		acceptColors = true,
		hideAtFullHealth = false,
		fontName = FONT,
		fontColor = WHITE,
		fontSize =  10,
		fontFlags = 'OUTLINE',
		JustifyH = 'CENTER',
		JustifyV = 'MIDDLE',
		textFormat = 1,		
	},	
	NameText = {
		acceptColors = true,	
		left = 0, top = 15,	width = false, height = 20,
		fontName = FONT,
		fontColor = WHITE,
		fontSize =  11,
		fontFlags = 'OUTLINE',
		JustifyH = 'CENTER',
		JustifyV = 'BOTTOM',
	},
	LevelText = {
		acceptColors = true,
		left = false, top = false,	width = false, height = false,
		fontName = FONT,
		fontColor = WHITE,
		fontSize =  10,
		fontFlags = 'OUTLINE',
		JustifyH = 'RIGHT',
		JustifyV = 'MIDDLE',
	},
	TargetIcon = {
		left = 0, top = 16, width = 22, height = 22,
	},
	CastBar = {
		left = 0, top = -15, width = false, height = 12,		
		barTexture = 'Gradient',
		backColor = { 0.2, 0.2, 0.2, 1 },
		borderSize = 1,
		borderColor = BLACK,
		SpellIcon = {
			left = -81, top = 8, width = 26, height = 26,
			borderSize  = 1,
			borderColor = BLACK,
		},
		SpellText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  9,
			fontFlags = 'OUTLINE',
			JustifyH = 'LEFT',
			JustifyV = 'MIDDLE',
			AdjustX = 0,
			AdjustY = 0,
		},
		TimeText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  9,
			fontFlags = 'OUTLINE',
			JustifyH = 'RIGHT',
			JustifyV = 'MIDDLE',
			AdjustX = 0,
			AdjustY = 0,
		},
	},
	Auras = {
		left = -54, top = 27, 
		auraWidth = 22, auraHeight = 16, auraSpacing = 2,
		borderSize = 1,
		borderColor = BLACK,
		TimeText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  11,
			fontFlags = 'OUTLINE',
			JustifyH = 'LEFT',
			JustifyV = 'TOP',
			AdjustX = -1,
			AdjustY = 8,
		},
		CountText = {
			fontName = FONT,
			fontColor = WHITE,
			fontSize =  9,
			fontFlags = 'OUTLINE',
			JustifyH = 'RIGHT',
			JustifyV = 'BOTTOM',	
			AdjustX = 0,
			AdjustY = 0,
		},
	},
} )

KiwiPlates:RegisterSkin( 'Squared.Small' , {
	Plate = { 
		left = 0, top = -20, width  = 75,	height =  9, 
	},
	Target    = { disableHighlight = false, color = HIGHLIGHT },
	Mouseover = { disableHighlight = false, color = HIGHLIGHT },
	GlowBorder = {
		acceptColors = true,
		color = TRANSPARENT,
	},
	HealthBar = {
		acceptColors = true,
		color 		= WHITE,		
		barTexture  = 'Gradient',
		backColor   = DARKGRAY,
		borderColor = BLACK,
		borderSize  = 1,
	},
	NameText = {
		acceptColors = true,
		left = 0, top = 13,	width = 150, height = 20,
		fontName = FONT_SMALL,
		fontColor = WHITE,
		fontSize =  12,
		fontFlags = 'OUTLINE',
		JustifyH = 'CENTER',
		JustifyV = 'BOTTOM',
	},
	TargetIcon = {
		left = 0, top = 13, width = 22, height = 22,
	},
} )

KiwiPlates:RegisterWidgetTexture( 'ClassificationIcon', 'star',  "Interface\\Addons\\KiwiPlates\\media\\star" )
KiwiPlates:RegisterWidgetTexture( 'ClassificationIcon', 'skull',  "Interface\\TargetingFrame\\UI-TargetingFrame-Skull" )

